@@ -562,16 +562,18 @@ class Struct(ScaleType):
 
 class Set(ScaleType):
     value_list = []
+    value_type = 'u64'
 
     def __init__(self, data, value_list=None, **kwargs):
         self.set_value = None
+
         if value_list:
             self.value_list = value_list
 
         super().__init__(data, **kwargs)
 
     def process(self):
-        self.set_value = self.process_type('u64').value
+        self.set_value = self.process_type(self.value_type).value
         result = []
         if self.set_value > 0:
 
@@ -589,12 +591,11 @@ class Set(ScaleType):
             if item in value:
                 result += set_mask
 
-        u64_obj = self.get_decoder_class('u64')
+        u64_obj = self.get_decoder_class(self.value_type)
 
         return u64_obj.encode(result)
 
 
-
 class Era(ScaleType):
 
     def process(self):
@@ -1240,7 +1241,7 @@ class ReportIdOf(Hash):
 
 class StorageHasher(Enum):
 
-    value_list = ['Blake2_128', 'Blake2_256', 'Blake2_128Concat', 'Twox128', 'Twox256', 'Twox64Concat']
+    value_list = ['Blake2_128', 'Blake2_256', 'Blake2_128Concat', 'Twox128', 'Twox256', 'Twox64Concat', 'Identity']
 
     def is_blake2_128(self):
         return self.index == 0
@@ -1260,6 +1261,9 @@ class StorageHasher(Enum):
     def is_twox64_concat(self):
         return self.index == 5
 
+    def is_identity(self):
+        return self.index == 6
+
 
 class VoterInfo(Struct):
     type_string = 'VoterInfo<Balance>'
